package com.srs.teacher.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;
import com.srs.teacher.mapper.SysTeacherHonorMapper;
import com.srs.teacher.domain.SysTeacherHonor;
import com.srs.teacher.service.ISysTeacherHonorService;

/**
 * honorService业务层处理
 *
 * @author srs
 * @date 2024-06-29
 */
@Service
public class SysTeacherHonorServiceImpl extends ServiceImpl<SysTeacherHonorMapper,SysTeacherHonor> implements ISysTeacherHonorService {
    @Autowired
    private SysTeacherHonorMapper sysTeacherHonorMapper;

    /**
     * 查询honor
     *
     * @param honorId honor主键
     * @return honor
     */
    @Override
    public SysTeacherHonor selectSysTeacherHonorByHonorId(Long honorId) {
        return sysTeacherHonorMapper.selectSysTeacherHonorByHonorId(honorId);
    }

    /**
     * 查询honor列表
     *
     * @param sysTeacherHonor honor
     * @return honor
     */
    @Override
    public List<SysTeacherHonor> selectSysTeacherHonorList(SysTeacherHonor sysTeacherHonor) {
        return sysTeacherHonorMapper.selectSysTeacherHonorList(sysTeacherHonor);
    }

    /**
     * 新增honor
     *
     * @param sysTeacherHonor honor
     * @return 结果
     */
    @Override
    public int insertSysTeacherHonor(SysTeacherHonor sysTeacherHonor) {
            return sysTeacherHonorMapper.insertSysTeacherHonor(sysTeacherHonor);
    }

    /**
     * 修改honor
     *
     * @param sysTeacherHonor honor
     * @return 结果
     */
    @Override
    public int updateSysTeacherHonor(SysTeacherHonor sysTeacherHonor) {
        return sysTeacherHonorMapper.updateSysTeacherHonor(sysTeacherHonor);
    }

    /**
     * 批量删除honor
     *
     * @param honorIds 需要删除的honor主键
     * @return 结果
     */
    @Override
    public int deleteSysTeacherHonorByHonorIds(Long[] honorIds) {
        return sysTeacherHonorMapper.deleteSysTeacherHonorByHonorIds(honorIds);
    }

    /**
     * 删除honor信息
     *
     * @param honorId honor主键
     * @return 结果
     */
    @Override
    public int deleteSysTeacherHonorByHonorId(Long honorId) {
        return sysTeacherHonorMapper.deleteSysTeacherHonorByHonorId(honorId);
    }
}
